``BarContainer`` properties
---------------------------
`.BarContainer` gained new properties to easily access coordinates of the bars:

- `~.BarContainer.bottoms`
- `~.BarContainer.tops`
- `~.BarContainer.position_centers`
